@@ -41,7 +41,7 @@ except:
     print "SIP v3.9 or later installed."
     sys.exit(1)
 
-config = sipconfig.SIPConfig("PyQt 3.15.1")
+config = sipconfig.SIPConfig("PyQt 3.16")
 
 
 # Initialise the globals.
